[mpich-commits] [mpich] MPICH primary repository branch, master, updated. v3.0.4-227-g01e95cb

mysql vizuser noreply at mpich.org
Sat May 18 21:05:59 CDT 2013


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "MPICH primary repository".

The branch, master has been updated
       via  01e95cbfc0dde9fac3180addb7981f4d199a235c (commit)
       via  9560e258f1840bd541495e6cf76c9a239c1b91d1 (commit)
      from  c655784c9703992d037562fac82ad0536b3e9fe1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.mpich.org/mpich.git/commitdiff/01e95cbfc0dde9fac3180addb7981f4d199a235c

commit 01e95cbfc0dde9fac3180addb7981f4d199a235c
Author: Pavan Balaji <balaji at mcs.anl.gov>
Date:   Sat May 18 21:05:31 2013 -0500

    Warning squash.
    
    No reviewer.

diff --git a/src/pm/hydra/pm/pmiserv/pmiserv_pmi.c b/src/pm/hydra/pm/pmiserv/pmiserv_pmi.c
index 87e015c..02fcbcc 100644
--- a/src/pm/hydra/pm/pmiserv/pmiserv_pmi.c
+++ b/src/pm/hydra/pm/pmiserv/pmiserv_pmi.c
@@ -65,7 +65,7 @@ HYD_status HYD_pmcd_pmi_publish(char *name, char *port, int *success)
     struct HYD_pmcd_pmi_publish *r, *publish;
     struct HYD_string_stash stash;
     char *ns, *ns_host, *ns_port_str;
-    int ns_port, ns_fd, i;
+    int ns_port, ns_fd;
     HYD_status status = HYD_SUCCESS;
 
     HYDU_FUNC_ENTER();
@@ -157,7 +157,7 @@ HYD_status HYD_pmcd_pmi_unpublish(char *name, int *success)
     struct HYD_pmcd_pmi_publish *r, *publish;
     struct HYD_string_stash stash;
     char *ns, *ns_host, *ns_port_str;
-    int ns_port, ns_fd, i;
+    int ns_port, ns_fd;
     HYD_status status = HYD_SUCCESS;
 
     HYDU_FUNC_ENTER();
@@ -250,7 +250,7 @@ HYD_status HYD_pmcd_pmi_lookup(char *name, char **value)
     struct HYD_pmcd_pmi_publish *publish;
     struct HYD_string_stash stash;
     char *ns, *ns_host, *ns_port_str;
-    int ns_port, ns_fd, i;
+    int ns_port, ns_fd;
     HYD_status status = HYD_SUCCESS;
 
     HYDU_FUNC_ENTER();

http://git.mpich.org/mpich.git/commitdiff/9560e258f1840bd541495e6cf76c9a239c1b91d1

commit 9560e258f1840bd541495e6cf76c9a239c1b91d1
Author: Pavan Balaji <balaji at mcs.anl.gov>
Date:   Sat May 18 21:03:29 2013 -0500

    Correct parameter name.
    
    Thanks to Jeff Hammond for reporting it.
    
    No reviewer.

diff --git a/src/include/mpiutil.h b/src/include/mpiutil.h
index ae03f78..221f990 100644
--- a/src/include/mpiutil.h
+++ b/src/include/mpiutil.h
@@ -43,7 +43,7 @@ const char *MPIU_Strerror(int errnum);
  * MPIU_Busy_wait()
  *
  * Call this in every busy wait loop to periodically yield the processor.  The
  * MPIR_PARAM_POLLS_BEFORE_YIELD parameter can be used to adjust the number of
  * times MPIU_Busy_wait is called before the yield function is called.
  */
 #ifdef USE_NOTHING_FOR_YIELD
@@ -54,9 +54,9 @@ const char *MPIU_Strerror(int errnum);
    need to be changed for fine-grained multithreading.  A possible alternative
    is to make it a global thread-local variable. */
 #define MPIU_Busy_wait() do {                                   \
-        if (MPIR_PARAM_POLLS_BEFORE_YIELD) {                    \
+        if (MPIR_PARAM_NEMESIS_POLLS_BEFORE_YIELD) {                    \
             static int poll_count_ = 0;                         \
-            if (poll_count_ >= MPIR_PARAM_POLLS_BEFORE_YIELD) { \
+            if (poll_count_ >= MPIR_PARAM_NEMESIS_POLLS_BEFORE_YIELD) { \
                 poll_count_ = 0;                                \
                 MPIU_PW_Sched_yield();                          \
             } else {                                            \

-----------------------------------------------------------------------

Summary of changes:
 src/include/mpiutil.h                 |    6 +++---
@@ -43,7 +43,7 @@ const char *MPIU_Strerror(int errnum);
  *
  * Call this in every busy wait loop to periodically yield the processor.  The
- * MPIR_PARAM_POLLS_BEFORE_YIELD parameter can be used to adjust the number of
+ * MPIR_PARAM_NEMESIS_POLLS_BEFORE_YIELD parameter can be used to adjust the number of
  * times MPIU_Busy_wait is called before the yield function is called.
  */
 src/pm/hydra/pm/pmiserv/pmiserv_pmi.c |    6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
MPICH primary repository


More information about the commits mailing list